pub struct CreateAgentSkillBuilder { /* private fields */ }Expand description
Builder for creating a agent skill
Implementations
Sourceimpl CreateAgentSkillBuilder
impl CreateAgentSkillBuilder
Sourcepub fn with_storage_location(
self,
storage_location: impl Into<Option<String>>,
) -> Self
pub fn with_storage_location( self, storage_location: impl Into<Option<String>>, ) -> Self
The storage location of the skill directory on the cloud.
Required for EXTERNAL skills; ignored (server-derived) for MANAGED skills.
Sourcepub fn with_description(self, description: impl Into<Option<String>>) -> Self
pub fn with_description(self, description: impl Into<Option<String>>) -> Self
A human-readable description of what the skill does and when to use it.
Sourcepub fn with_license(self, license: impl Into<Option<String>>) -> Self
pub fn with_license(self, license: impl Into<Option<String>>) -> Self
SPDX license identifier or free-form license text for the skill.
Sourcepub fn with_allowed_tools<I>(self, allowed_tools: I) -> Selfwhere
I: IntoIterator<Item = String>,
pub fn with_allowed_tools<I>(self, allowed_tools: I) -> Selfwhere
I: IntoIterator<Item = String>,
The tools the skill is permitted to use.
Sourcepub fn with_metadata<I, K, V>(self, metadata: I) -> Self
pub fn with_metadata<I, K, V>(self, metadata: I) -> Self
Arbitrary additional metadata declared by the skill.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
User-provided free-form text description.