pub struct UpdateAgentBuilder { /* private fields */ }Expand description
Builder for updating a agent
Implementations
Sourceimpl UpdateAgentBuilder
impl UpdateAgentBuilder
Sourcepub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
pub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
New name for the agent.
Sourcepub fn with_invocation_protocol(
self,
invocation_protocol: impl Into<Option<InvocationProtocol>>,
) -> Self
pub fn with_invocation_protocol( self, invocation_protocol: impl Into<Option<InvocationProtocol>>, ) -> Self
The protocol a recipient uses to invoke the agent.
Sourcepub fn with_endpoint(self, endpoint: impl Into<Option<String>>) -> Self
pub fn with_endpoint(self, endpoint: impl Into<Option<String>>) -> Self
The agent’s invocation endpoint URL.
Sourcepub fn with_description(self, description: impl Into<Option<String>>) -> Self
pub fn with_description(self, description: impl Into<Option<String>>) -> Self
Updated LLM-readable description.
Sourcepub fn with_capabilities<I>(self, capabilities: I) -> Selfwhere
I: IntoIterator<Item = String>,
pub fn with_capabilities<I>(self, capabilities: I) -> Selfwhere
I: IntoIterator<Item = String>,
Updated capability identifiers advertised by the agent.
Sourcepub fn with_input_schema(self, input_schema: impl Into<Option<String>>) -> Self
pub fn with_input_schema(self, input_schema: impl Into<Option<String>>) -> Self
Updated JSON Schema (encoded as a JSON string) describing the expected input.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
The comment attached to the agent.
Sourcepub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
pub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
The identifier of the user who owns the agent.