pub struct CreateCatalogBuilder { /* private fields */ }Expand description
Builder for creating a catalog
Implementations
Sourceimpl CreateCatalogBuilder
impl CreateCatalogBuilder
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
User-provided free-form text description.
Sourcepub fn with_properties<I, K, V>(self, properties: I) -> Self
pub fn with_properties<I, K, V>(self, properties: I) -> Self
A map of key-value properties attached to the securable.
Sourcepub fn with_storage_root(self, storage_root: impl Into<Option<String>>) -> Self
pub fn with_storage_root(self, storage_root: impl Into<Option<String>>) -> Self
Storage root URL for managed tables within catalog.
Sourcepub fn with_provider_name(
self,
provider_name: impl Into<Option<String>>,
) -> Self
pub fn with_provider_name( self, provider_name: impl Into<Option<String>>, ) -> Self
The name of delta sharing provider.
A Delta Sharing catalog is a catalog that is based on a Delta share on a remote sharing server.
The name of the share under the share provider.