pub struct ListCatalogsBuilder { /* private fields */ }Expand description
Builder for listing catalogs
Implementations
Sourceimpl ListCatalogsBuilder
impl ListCatalogsBuilder
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn into_stream(self) -> BoxStream<'static, Result<Catalog>>
pub fn into_stream(self) -> BoxStream<'static, Result<Catalog>>
Convert paginated request into stream of results