pub struct CatalogClient { /* private fields */ }Expand description
A client scoped to a single catalog.
Implementations
Sourceimpl CatalogClient
impl CatalogClient
Sourcepub fn new(
catalog_name: impl Into<String>,
client: CatalogServiceClient,
) -> Self
pub fn new( catalog_name: impl Into<String>, client: CatalogServiceClient, ) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn get(&self) -> GetCatalogBuilder
pub fn get(&self) -> GetCatalogBuilder
Get a catalog
Gets the specified catalog in a metastore. The caller must be a metastore admin, the owner of the catalog, or a user that has the USE_CATALOG privilege set for their account.
Sourcepub fn update(&self) -> UpdateCatalogBuilder
pub fn update(&self) -> UpdateCatalogBuilder
Update a catalog
Updates the catalog that matches the supplied name. The caller must be either the owner of the catalog, or a metastore admin (when changing the owner field of the catalog).
Sourcepub fn delete(&self) -> DeleteCatalogBuilder
pub fn delete(&self) -> DeleteCatalogBuilder
Delete a catalog
Deletes the catalog that matches the supplied name. The caller must be a metastore admin or the owner of the catalog.
Sourcepub fn schema(&self, schema_name: impl Into<String>) -> SchemaClient
pub fn schema(&self, schema_name: impl Into<String>) -> SchemaClient
Access a schema within this resource.
Sourcepub fn create_schema(&self, name: impl Into<String>) -> CreateSchemaBuilder
pub fn create_schema(&self, name: impl Into<String>) -> CreateSchemaBuilder
Create a schema within this resource.
Sourcepub fn list_schemas(&self) -> ListSchemasBuilder
pub fn list_schemas(&self) -> ListSchemasBuilder
List schema resources within this resource.