pub struct CreateCredentialBuilder { /* private fields */ }Expand description
Builder for creating a credential
Implementations
Sourceimpl CreateCredentialBuilder
impl CreateCredentialBuilder
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
Comment associated with the credential.
Sourcepub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
pub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
Whether the credential is usable only for read operations. Only applicable when purpose is STORAGE.
Sourcepub fn with_skip_validation(
self,
skip_validation: impl Into<Option<bool>>,
) -> Self
pub fn with_skip_validation( self, skip_validation: impl Into<Option<bool>>, ) -> Self
Optional. Supplying true to this argument skips validation of the created set of credentials.
Sourcepub fn with_azure_service_principal(
self,
azure_service_principal: impl Into<Option<AzureServicePrincipal>>,
) -> Self
pub fn with_azure_service_principal( self, azure_service_principal: impl Into<Option<AzureServicePrincipal>>, ) -> Self
The Azure service principal configuration.
Sourcepub fn with_azure_managed_identity(
self,
azure_managed_identity: impl Into<Option<AzureManagedIdentity>>,
) -> Self
pub fn with_azure_managed_identity( self, azure_managed_identity: impl Into<Option<AzureManagedIdentity>>, ) -> Self
The Azure managed identity configuration.
Sourcepub fn with_azure_storage_key(
self,
azure_storage_key: impl Into<Option<AzureStorageKey>>,
) -> Self
pub fn with_azure_storage_key( self, azure_storage_key: impl Into<Option<AzureStorageKey>>, ) -> Self
The Azure storage key configuration.
Sourcepub fn with_aws_iam_role(
self,
aws_iam_role: impl Into<Option<AwsIamRoleConfig>>,
) -> Self
pub fn with_aws_iam_role( self, aws_iam_role: impl Into<Option<AwsIamRoleConfig>>, ) -> Self
The AWS IAM role configuration.
Sourcepub fn with_databricks_gcp_service_account(
self,
databricks_gcp_service_account: impl Into<Option<DatabricksGcpServiceAccount>>,
) -> Self
pub fn with_databricks_gcp_service_account( self, databricks_gcp_service_account: impl Into<Option<DatabricksGcpServiceAccount>>, ) -> Self
The Databricks managed GCP service account configuration.