pub struct ListCredentialsBuilder { /* private fields */ }Expand description
Builder for listing credentials
Implementations
Sourceimpl ListCredentialsBuilder
impl ListCredentialsBuilder
Sourcepub fn with_purpose(self, purpose: impl Into<Option<Purpose>>) -> Self
pub fn with_purpose(self, purpose: impl Into<Option<Purpose>>) -> Self
Return only credentials for the specified purpose.
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn into_stream(self) -> BoxStream<'static, Result<Credential>>
pub fn into_stream(self) -> BoxStream<'static, Result<Credential>>
Convert paginated request into stream of results