pub struct UpdateCredentialBuilder { /* private fields */ }Expand description
Builder for updating a credential
Implementations
Sourceimpl UpdateCredentialBuilder
impl UpdateCredentialBuilder
Sourcepub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
pub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
New name of the credential.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
Comment associated with the credential.
Sourcepub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
pub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
Whether the credential is usable only for read operations. Only applicable when purpose is STORAGE.
Sourcepub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
pub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
Username of current owner of credential.
Sourcepub fn with_skip_validation(
self,
skip_validation: impl Into<Option<bool>>,
) -> Self
pub fn with_skip_validation( self, skip_validation: impl Into<Option<bool>>, ) -> Self
Supply true to this argument to skip validation of the updated credential.
Sourcepub fn with_force(self, force: impl Into<Option<bool>>) -> Self
pub fn with_force(self, force: impl Into<Option<bool>>) -> Self
Force an update even if there are dependent services (when purpose is SERVICE) or dependent external locations and external tables (when purpose is STORAGE).
Sourcepub fn with_azure_service_principal(
self,
azure_service_principal: impl Into<Option<AzureServicePrincipal>>,
) -> Self
pub fn with_azure_service_principal( self, azure_service_principal: impl Into<Option<AzureServicePrincipal>>, ) -> Self
The Azure service principal configuration.
Sourcepub fn with_azure_managed_identity(
self,
azure_managed_identity: impl Into<Option<AzureManagedIdentity>>,
) -> Self
pub fn with_azure_managed_identity( self, azure_managed_identity: impl Into<Option<AzureManagedIdentity>>, ) -> Self
The Azure managed identity configuration.
Sourcepub fn with_azure_storage_key(
self,
azure_storage_key: impl Into<Option<AzureStorageKey>>,
) -> Self
pub fn with_azure_storage_key( self, azure_storage_key: impl Into<Option<AzureStorageKey>>, ) -> Self
The Azure storage key configuration.
Sourcepub fn with_aws_iam_role(
self,
aws_iam_role: impl Into<Option<AwsIamRoleConfig>>,
) -> Self
pub fn with_aws_iam_role( self, aws_iam_role: impl Into<Option<AwsIamRoleConfig>>, ) -> Self
The AWS IAM role configuration.
Sourcepub fn with_databricks_gcp_service_account(
self,
databricks_gcp_service_account: impl Into<Option<DatabricksGcpServiceAccount>>,
) -> Self
pub fn with_databricks_gcp_service_account( self, databricks_gcp_service_account: impl Into<Option<DatabricksGcpServiceAccount>>, ) -> Self
The Databricks managed GCP service account configuration.