pub struct UpdateExternalLocationBuilder { /* private fields */ }Expand description
Builder for updating a external location
Implementations
Sourceimpl UpdateExternalLocationBuilder
impl UpdateExternalLocationBuilder
Sourcepub fn with_url(self, url: impl Into<Option<String>>) -> Self
pub fn with_url(self, url: impl Into<Option<String>>) -> Self
Path URL of the external location.
Sourcepub fn with_credential_name(
self,
credential_name: impl Into<Option<String>>,
) -> Self
pub fn with_credential_name( self, credential_name: impl Into<Option<String>>, ) -> Self
Name of the storage credential used with this location.
Sourcepub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
pub fn with_read_only(self, read_only: impl Into<Option<bool>>) -> Self
Indicates whether the external location is read-only.
Sourcepub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
pub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
owner of the external location.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
User-provided free-form text description.
Sourcepub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
pub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
new name of the external location.
Sourcepub fn with_force(self, force: impl Into<Option<bool>>) -> Self
pub fn with_force(self, force: impl Into<Option<bool>>) -> Self
force update of the external location.
Sourcepub fn with_skip_validation(
self,
skip_validation: impl Into<Option<bool>>,
) -> Self
pub fn with_skip_validation( self, skip_validation: impl Into<Option<bool>>, ) -> Self
Skips validation of the storage credential associated with the external location.