FunctionClient

Struct FunctionClient 

pub struct FunctionClient { /* private fields */ }
A client scoped to a single function.

Implementations

Source

impl FunctionClient

pub fn new( catalog_name: impl Into<String>, schema_name: impl Into<String>, function_name: impl Into<String>, client: FunctionServiceClient, ) -> Self

Create a client bound to the resource’s name components.

pub fn from_full_name( full_name: impl Into<String>, client: FunctionServiceClient, ) -> Self

Create a function client from its dot-joined full name (e.g. "catalog_name.schema_name.function_name").

pub fn catalog_name(&self) -> &str

The catalog_name component of this resource’s name.

pub fn schema_name(&self) -> &str

The schema_name component of this resource’s name.

pub fn name(&self) -> &str

This resource’s own name (the leaf component).

pub fn full_name(&self) -> String

The fully-qualified name of this resource (its dot-joined name components).

pub fn get(&self) -> GetFunctionBuilder

Get a function

Gets a function from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the function, or have SELECT on the function.

pub fn update(&self) -> UpdateFunctionBuilder

Update a function

Updates the function that matches the supplied name. Only the owner of the function can be updated.

pub fn delete(&self) -> DeleteFunctionBuilder

Delete a function

Deletes the function that matches the supplied name. For the deletion to succeed, the caller must be the owner of the function.