pub struct GetModelVersionBuilder { /* private fields */ }Expand description
Builder for getting a model version
Implementations
Sourceimpl GetModelVersionBuilder
impl GetModelVersionBuilder
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include model versions in the response for which the principal can only access selective metadata for.