pub struct PolicyServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
Sourceimpl PolicyServiceClient
impl PolicyServiceClient
Sourcepub async fn list_policies(
&self,
request: &ListPoliciesRequest,
) -> Result<ListPoliciesResponse>
pub async fn list_policies( &self, request: &ListPoliciesRequest, ) -> Result<ListPoliciesResponse>
List policies
Gets an array of policies defined on the specified securable. There is no guarantee of a specific ordering of the elements in the array.
Sourcepub async fn create_policy(
&self,
request: &CreatePolicyRequest,
) -> Result<PolicyInfo>
pub async fn create_policy( &self, request: &CreatePolicyRequest, ) -> Result<PolicyInfo>
Create a new policy
Creates a new row-filter or column-mask policy on the specified securable.
Sourcepub async fn get_policy(&self, request: &GetPolicyRequest) -> Result<PolicyInfo>
pub async fn get_policy(&self, request: &GetPolicyRequest) -> Result<PolicyInfo>
Get a policy
Gets the policy that matches the supplied name, defined on the specified securable.
Sourcepub async fn update_policy(
&self,
request: &UpdatePolicyRequest,
) -> Result<PolicyInfo>
pub async fn update_policy( &self, request: &UpdatePolicyRequest, ) -> Result<PolicyInfo>
Update a policy
Updates the policy that matches the supplied name, defined on the specified securable.
Sourcepub async fn delete_policy(&self, request: &DeletePolicyRequest) -> Result<()>
pub async fn delete_policy(&self, request: &DeletePolicyRequest) -> Result<()>
Delete a policy
Deletes the policy that matches the supplied name, defined on the specified securable.