pub struct PolicyClient { /* private fields */ }Expand description
A client scoped to a single policy.
Implementations
Sourceimpl PolicyClient
impl PolicyClient
Sourcepub fn new(policy_name: impl Into<String>, client: PolicyServiceClient) -> Self
pub fn new(policy_name: impl Into<String>, client: PolicyServiceClient) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn create_policy(&self, policy_info: PolicyInfo) -> CreatePolicyBuilder
pub fn create_policy(&self, policy_info: PolicyInfo) -> CreatePolicyBuilder
Create a new policy
Creates a new row-filter or column-mask policy on the specified securable.
Sourcepub fn get(&self) -> GetPolicyBuilder
pub fn get(&self) -> GetPolicyBuilder
Get a policy
Gets the policy that matches the supplied name, defined on the specified securable.
Sourcepub fn update(&self, policy_info: PolicyInfo) -> UpdatePolicyBuilder
pub fn update(&self, policy_info: PolicyInfo) -> UpdatePolicyBuilder
Update a policy
Updates the policy that matches the supplied name, defined on the specified securable.
Sourcepub fn delete(&self) -> DeletePolicyBuilder
pub fn delete(&self) -> DeletePolicyBuilder
Delete a policy
Deletes the policy that matches the supplied name, defined on the specified securable.