pub struct ListProvidersBuilder { /* private fields */ }Expand description
Builder for listing providers
Implementations
Sourceimpl ListProvidersBuilder
impl ListProvidersBuilder
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn into_stream(self) -> BoxStream<'static, Result<Provider>>
pub fn into_stream(self) -> BoxStream<'static, Result<Provider>>
Convert paginated request into stream of results