pub struct UpdateProviderBuilder { /* private fields */ }Expand description
Builder for updating a provider
Implementations
Sourceimpl UpdateProviderBuilder
impl UpdateProviderBuilder
Sourcepub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
pub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
New name for the provider.
Sourcepub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
pub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
Username of the provider owner.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
Description about the provider.
Sourcepub fn with_recipient_profile_str(
self,
recipient_profile_str: impl Into<Option<String>>,
) -> Self
pub fn with_recipient_profile_str( self, recipient_profile_str: impl Into<Option<String>>, ) -> Self
The recipient profile (credential file contents) used to connect to the sharing server.
Sourcepub fn with_properties<I, K, V>(self, properties: I) -> Self
pub fn with_properties<I, K, V>(self, properties: I) -> Self
Provider properties as map of string key-value pairs.
When provided in update request, the specified properties will override the existing properties. To add and remove properties, one would need to perform a read-modify-write.