pub struct UpdateRecipientBuilder { /* private fields */ }Expand description
Builder for updating a recipient
Implementations
Sourceimpl UpdateRecipientBuilder
impl UpdateRecipientBuilder
Sourcepub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
pub fn with_new_name(self, new_name: impl Into<Option<String>>) -> Self
New name for the recipient
Sourcepub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
pub fn with_owner(self, owner: impl Into<Option<String>>) -> Self
Username of the recipient owner.
Sourcepub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
pub fn with_comment(self, comment: impl Into<Option<String>>) -> Self
Description about the recipient.
Sourcepub fn with_properties<I, K, V>(self, properties: I) -> Self
pub fn with_properties<I, K, V>(self, properties: I) -> Self
Recipient properties as map of string key-value pairs.
When provided in update request, the specified properties will override the existing properties. To add and remove properties, one would need to perform a read-modify-write.
Sourcepub fn with_expiration_time(
self,
expiration_time: impl Into<Option<i64>>,
) -> Self
pub fn with_expiration_time( self, expiration_time: impl Into<Option<i64>>, ) -> Self
Expiration timestamp of the token, in epoch milliseconds.