pub struct GetRegisteredModelBuilder { /* private fields */ }Expand description
Builder for getting a registered model
Implementations
Sourceimpl GetRegisteredModelBuilder
impl GetRegisteredModelBuilder
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include registered models in the response for which the principal can only access selective metadata for.