RegisteredModelServiceClient

Struct RegisteredModelServiceClient 

pub struct RegisteredModelServiceClient { /* private fields */ }
HTTP client for service operations

Implementations

Source

impl RegisteredModelServiceClient

pub fn new(client: Transport, base_url: Url) -> Self

Create a new client instance

pub async fn list_registered_models( &self, request: &ListRegisteredModelsRequest, ) -> Result<ListRegisteredModelsResponse>

List registered models

List registered models within the specified parent catalog and schema. If the caller is the metastore admin, all registered models are returned in the response. Otherwise, the caller must have USE_CATALOG on the parent catalog and USE_SCHEMA on the parent schema, and the model must either be owned by the caller or the caller must have a privilege on the model.

pub async fn create_registered_model( &self, request: &CreateRegisteredModelRequest, ) -> Result<RegisteredModel>

Create a registered model

Creates a new registered model. The caller must be a metastore admin or have the CREATE_MODEL privilege on the parent catalog and schema.

pub async fn get_registered_model( &self, request: &GetRegisteredModelRequest, ) -> Result<RegisteredModel>

Get a registered model

Gets a registered model from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the registered model, or have a privilege on the registered model.

pub async fn update_registered_model( &self, request: &UpdateRegisteredModelRequest, ) -> Result<RegisteredModel>

Update a registered model

Updates the registered model that matches the supplied name.

pub async fn delete_registered_model( &self, request: &DeleteRegisteredModelRequest, ) -> Result<()>

Delete a registered model

Deletes the registered model that matches the supplied name. For the deletion to succeed, the caller must be the owner of the registered model.