pub struct ListSchemasBuilder { /* private fields */ }Expand description
Builder for listing schemas
Implementations
Sourceimpl ListSchemasBuilder
impl ListSchemasBuilder
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include schemas in the response for which the principal can only access selective metadata for
Sourcepub fn into_stream(self) -> BoxStream<'static, Result<Schema>>
pub fn into_stream(self) -> BoxStream<'static, Result<Schema>>
Convert paginated request into stream of results