pub struct ShareServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
List shares.
Create a new share.
Get a share by name.
Update a share.
Deletes a share.
Sourcepub async fn get_permissions(
&self,
request: &GetPermissionsRequest,
) -> Result<GetPermissionsResponse>
pub async fn get_permissions( &self, request: &GetPermissionsRequest, ) -> Result<GetPermissionsResponse>
Gets the permissions for a data share from the metastore.
Sourcepub async fn update_permissions(
&self,
request: &UpdatePermissionsRequest,
) -> Result<UpdatePermissionsResponse>
pub async fn update_permissions( &self, request: &UpdatePermissionsRequest, ) -> Result<UpdatePermissionsResponse>
Updates the permissions for a data share in the metastore.