pub struct ShareClient { /* private fields */ }Expand description
A client scoped to a single share.
Implementations
Sourcepub fn new(share_name: impl Into<String>, client: ShareServiceClient) -> Self
pub fn new(share_name: impl Into<String>, client: ShareServiceClient) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn get(&self) -> GetShareBuilder
pub fn get(&self) -> GetShareBuilder
Get a share by name.
Sourcepub fn update(&self) -> UpdateShareBuilder
pub fn update(&self) -> UpdateShareBuilder
Update a share.
Sourcepub fn delete(&self) -> DeleteShareBuilder
pub fn delete(&self) -> DeleteShareBuilder
Deletes a share.
Sourcepub fn get_permissions(&self) -> GetPermissionsBuilder
pub fn get_permissions(&self) -> GetPermissionsBuilder
Gets the permissions for a data share from the metastore.
Sourcepub fn update_permissions(&self) -> UpdatePermissionsBuilder
pub fn update_permissions(&self) -> UpdatePermissionsBuilder
Updates the permissions for a data share in the metastore.