pub struct GetTableBuilder { /* private fields */ }Expand description
Builder for getting a table
Implementations
Sourceimpl GetTableBuilder
impl GetTableBuilder
Sourcepub fn with_include_delta_metadata(
self,
include_delta_metadata: impl Into<Option<bool>>,
) -> Self
pub fn with_include_delta_metadata( self, include_delta_metadata: impl Into<Option<bool>>, ) -> Self
Whether delta metadata should be included in the response.
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include tables in the response for which the principal can only access selective metadata for
Sourcepub fn with_include_manifest_capabilities(
self,
include_manifest_capabilities: impl Into<Option<bool>>,
) -> Self
pub fn with_include_manifest_capabilities( self, include_manifest_capabilities: impl Into<Option<bool>>, ) -> Self
Whether to include a manifest containing capabilities the table has.