pub struct ListTableSummariesBuilder { /* private fields */ }Expand description
Builder for table summaries
Implementations
Sourceimpl ListTableSummariesBuilder
impl ListTableSummariesBuilder
Sourcepub fn with_schema_name_pattern(
self,
schema_name_pattern: impl Into<Option<String>>,
) -> Self
pub fn with_schema_name_pattern( self, schema_name_pattern: impl Into<Option<String>>, ) -> Self
A sql LIKE pattern (% and _) for schema names. All schemas will be returned if not set or empty.
Sourcepub fn with_table_name_pattern(
self,
table_name_pattern: impl Into<Option<String>>,
) -> Self
pub fn with_table_name_pattern( self, table_name_pattern: impl Into<Option<String>>, ) -> Self
A sql LIKE pattern (% and _) for table names. All tables will be returned if not set or empty.
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn with_include_manifest_capabilities(
self,
include_manifest_capabilities: impl Into<Option<bool>>,
) -> Self
pub fn with_include_manifest_capabilities( self, include_manifest_capabilities: impl Into<Option<bool>>, ) -> Self
Whether to include a manifest containing capabilities the table has.