pub struct ListTablesBuilder { /* private fields */ }Expand description
Builder for listing tables
Implementations
Sourceimpl ListTablesBuilder
impl ListTablesBuilder
Sourcepub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
pub fn with_max_results(self, max_results: impl Into<Option<i32>>) -> Self
The maximum number of results per page that should be returned.
Sourcepub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
pub fn with_page_token(self, page_token: impl Into<Option<String>>) -> Self
Opaque pagination token to go to next page based on previous query.
Sourcepub fn with_include_delta_metadata(
self,
include_delta_metadata: impl Into<Option<bool>>,
) -> Self
pub fn with_include_delta_metadata( self, include_delta_metadata: impl Into<Option<bool>>, ) -> Self
Whether delta metadata should be included in the response.
Sourcepub fn with_omit_columns(self, omit_columns: impl Into<Option<bool>>) -> Self
pub fn with_omit_columns(self, omit_columns: impl Into<Option<bool>>) -> Self
Whether to omit the columns of the table from the response or not.
Sourcepub fn with_omit_properties(
self,
omit_properties: impl Into<Option<bool>>,
) -> Self
pub fn with_omit_properties( self, omit_properties: impl Into<Option<bool>>, ) -> Self
Whether to omit the properties of the table from the response or not.
Sourcepub fn with_omit_username(self, omit_username: impl Into<Option<bool>>) -> Self
pub fn with_omit_username(self, omit_username: impl Into<Option<bool>>) -> Self
Whether to omit the username of the table (e.g. owner, updated_by, created_by) from the response or not.
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include tables in the response for which the principal can only access selective metadata for
Sourcepub fn with_include_manifest_capabilities(
self,
include_manifest_capabilities: impl Into<Option<bool>>,
) -> Self
pub fn with_include_manifest_capabilities( self, include_manifest_capabilities: impl Into<Option<bool>>, ) -> Self
Whether to include a manifest containing capabilities the table has.
Sourcepub fn into_stream(self) -> BoxStream<'static, Result<Table>>
pub fn into_stream(self) -> BoxStream<'static, Result<Table>>
Convert paginated request into stream of results