GenerateTemporaryPathCredentialsBuilder

Struct GenerateTemporaryPathCredentialsBuilder 

pub struct GenerateTemporaryPathCredentialsBuilder { /* private fields */ }
Builder for temporary path credentials

Implementations

Source

impl GenerateTemporaryPathCredentialsBuilder

pub fn with_dry_run(self, dry_run: impl Into<Option<bool>>) -> Self

When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.