pub struct GetVolumeBuilder { /* private fields */ }Expand description
Builder for getting a volume
Implementations
Sourceimpl GetVolumeBuilder
impl GetVolumeBuilder
Sourcepub fn with_include_browse(
self,
include_browse: impl Into<Option<bool>>,
) -> Self
pub fn with_include_browse( self, include_browse: impl Into<Option<bool>>, ) -> Self
Whether to include schemas in the response for which the principal can only access selective metadata for