#[non_exhaustive]pub enum UcApiError {
InvalidParameter {
message: String,
},
Unauthenticated {
message: String,
},
PermissionDenied {
message: String,
},
NotFound {
message: String,
},
AlreadyExists {
message: String,
},
RequestLimitExceeded {
message: String,
},
InternalError {
message: String,
},
TemporarilyUnavailable {
message: String,
},
Other {
status: u16,
error_code: String,
message: String,
},
}Expand description
Typed error variants mapped to the Databricks Unity Catalog API error code spec.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidParameter
Unauthenticated
PermissionDenied
NotFound
AlreadyExists
RequestLimitExceeded
InternalError
Other
Implementations
Sourceimpl UcApiError
impl UcApiError
Sourcepub fn error_code(&self) -> &str
pub fn error_code(&self) -> &str
Returns the UC API error code string.
Sourcepub fn http_status(&self) -> u16
pub fn http_status(&self) -> u16
Returns the HTTP status code associated with this error.
Sourcepub fn from_api_response(status: u16, error_code: &str, message: String) -> Self
pub fn from_api_response(status: u16, error_code: &str, message: String) -> Self
Construct from an API response with status code, error code string, and message.