pub struct CatalogServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
Sourceimpl CatalogServiceClient
impl CatalogServiceClient
Sourcepub async fn list_catalogs(
&self,
request: &ListCatalogsRequest,
) -> Result<ListCatalogsResponse>
pub async fn list_catalogs( &self, request: &ListCatalogsRequest, ) -> Result<ListCatalogsResponse>
List catalogs
Gets an array of catalogs in the metastore. If the caller is the metastore admin, all catalogs will be retrieved. Otherwise, only catalogs owned by the caller (or for which the caller has the USE_CATALOG privilege) will be retrieved. There is no guarantee of a specific ordering of the elements in the array.
Sourcepub async fn create_catalog(
&self,
request: &CreateCatalogRequest,
) -> Result<Catalog>
pub async fn create_catalog( &self, request: &CreateCatalogRequest, ) -> Result<Catalog>
Create a new catalog
Creates a new catalog instance in the parent metastore if the caller is a metastore admin or has the CREATE_CATALOG privilege.
Sourcepub async fn get_catalog(&self, request: &GetCatalogRequest) -> Result<Catalog>
pub async fn get_catalog(&self, request: &GetCatalogRequest) -> Result<Catalog>
Get a catalog
Gets the specified catalog in a metastore. The caller must be a metastore admin, the owner of the catalog, or a user that has the USE_CATALOG privilege set for their account.
Sourcepub async fn update_catalog(
&self,
request: &UpdateCatalogRequest,
) -> Result<Catalog>
pub async fn update_catalog( &self, request: &UpdateCatalogRequest, ) -> Result<Catalog>
Update a catalog
Updates the catalog that matches the supplied name. The caller must be either the owner of the catalog, or a metastore admin (when changing the owner field of the catalog).
Sourcepub async fn delete_catalog(&self, request: &DeleteCatalogRequest) -> Result<()>
pub async fn delete_catalog(&self, request: &DeleteCatalogRequest) -> Result<()>
Delete a catalog
Deletes the catalog that matches the supplied name. The caller must be a metastore admin or the owner of the catalog.