pub struct UnityCatalogClient { /* private fields */ }Implementations
Sourceimpl UnityCatalogClient
impl UnityCatalogClient
Sourcepub fn new(client: Transport, base_url: Url) -> Self
pub fn new(client: Transport, base_url: Url) -> Self
Create a new aggregate client from a cloud client and base URL.
Per-service clients are constructed on demand (they only hold a cheaply-cloneable
CloudClient + Url), so nothing is allocated per service here.
Sourcepub fn new_unauthenticated(base_url: Url) -> Self
pub fn new_unauthenticated(base_url: Url) -> Self
Create a new aggregate client with no authentication.
Sourcepub fn new_with_token(base_url: Url, token: impl ToString) -> Self
pub fn new_with_token(base_url: Url, token: impl ToString) -> Self
Create a new aggregate client authenticating with a bearer token.
Sourcepub fn agent_skills_client(&self) -> AgentSkillServiceClient
pub fn agent_skills_client(&self) -> AgentSkillServiceClient
Low-level agent_skills client exposing request/response passthrough methods.
Sourcepub fn agents_client(&self) -> AgentServiceClient
pub fn agents_client(&self) -> AgentServiceClient
Low-level agents client exposing request/response passthrough methods.
Sourcepub fn catalogs_client(&self) -> CatalogServiceClient
pub fn catalogs_client(&self) -> CatalogServiceClient
Low-level catalogs client exposing request/response passthrough methods.
Sourcepub fn credentials_client(&self) -> CredentialServiceClient
pub fn credentials_client(&self) -> CredentialServiceClient
Low-level credentials client exposing request/response passthrough methods.
Sourcepub fn entity_tag_assignments_client(&self) -> EntityTagAssignmentClient
pub fn entity_tag_assignments_client(&self) -> EntityTagAssignmentClient
Low-level entity_tag_assignments client exposing request/response passthrough methods.
Sourcepub fn external_locations_client(&self) -> ExternalLocationServiceClient
pub fn external_locations_client(&self) -> ExternalLocationServiceClient
Low-level external_locations client exposing request/response passthrough methods.
Sourcepub fn functions_client(&self) -> FunctionServiceClient
pub fn functions_client(&self) -> FunctionServiceClient
Low-level functions client exposing request/response passthrough methods.
Sourcepub fn model_versions_client(&self) -> ModelVersionServiceClient
pub fn model_versions_client(&self) -> ModelVersionServiceClient
Low-level model_versions client exposing request/response passthrough methods.
Sourcepub fn policies_client(&self) -> PolicyServiceClient
pub fn policies_client(&self) -> PolicyServiceClient
Low-level policies client exposing request/response passthrough methods.
Sourcepub fn providers_client(&self) -> ProviderServiceClient
pub fn providers_client(&self) -> ProviderServiceClient
Low-level providers client exposing request/response passthrough methods.
Sourcepub fn recipients_client(&self) -> RecipientServiceClient
pub fn recipients_client(&self) -> RecipientServiceClient
Low-level recipients client exposing request/response passthrough methods.
Sourcepub fn registered_models_client(&self) -> RegisteredModelServiceClient
pub fn registered_models_client(&self) -> RegisteredModelServiceClient
Low-level registered_models client exposing request/response passthrough methods.
Sourcepub fn schemas_client(&self) -> SchemaServiceClient
pub fn schemas_client(&self) -> SchemaServiceClient
Low-level schemas client exposing request/response passthrough methods.
Low-level shares client exposing request/response passthrough methods.
Sourcepub fn staging_tables_client(&self) -> StagingTableServiceClient
pub fn staging_tables_client(&self) -> StagingTableServiceClient
Low-level staging_tables client exposing request/response passthrough methods.
Sourcepub fn tables_client(&self) -> TableServiceClient
pub fn tables_client(&self) -> TableServiceClient
Low-level tables client exposing request/response passthrough methods.
Sourcepub fn tag_policies_client(&self) -> TagPolicyServiceClient
pub fn tag_policies_client(&self) -> TagPolicyServiceClient
Low-level tag_policies client exposing request/response passthrough methods.
Sourcepub fn temporary_credentials_client(&self) -> TemporaryCredentialClient
pub fn temporary_credentials_client(&self) -> TemporaryCredentialClient
Low-level temporary_credentials client exposing request/response passthrough methods.
Sourcepub fn volumes_client(&self) -> VolumeServiceClient
pub fn volumes_client(&self) -> VolumeServiceClient
Low-level volumes client exposing request/response passthrough methods.
Sourcepub fn list_agent_skills(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> ListAgentSkillsBuilder
pub fn list_agent_skills( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> ListAgentSkillsBuilder
Lists agent skills.
Arguments
catalog_name- The identifier of the catalog.schema_name- The identifier of the schema.
Sourcepub fn create_agent_skill(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
name: impl Into<String>,
agent_skill_type: AgentSkillType,
) -> CreateAgentSkillBuilder
pub fn create_agent_skill( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, name: impl Into<String>, agent_skill_type: AgentSkillType, ) -> CreateAgentSkillBuilder
Arguments
catalog_name- The identifier of the catalog.schema_name- The identifier of the schema.name- The identifier of the agent skill.agent_skill_type- How the storage location is provisioned (external or managed).
Sourcepub fn agent_skill(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
agent_skill_name: impl Into<String>,
) -> AgentSkillClient
pub fn agent_skill( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, agent_skill_name: impl Into<String>, ) -> AgentSkillClient
Access the agent_skill resource scoped to the given name.
Sourcepub fn agent_skill_from_full_name(
&self,
full_name: impl Into<String>,
) -> AgentSkillClient
pub fn agent_skill_from_full_name( &self, full_name: impl Into<String>, ) -> AgentSkillClient
Access the agent_skill resource from its dot-joined full name.
Sourcepub fn list_agents(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> ListAgentsBuilder
pub fn list_agents( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> ListAgentsBuilder
Lists agents.
Arguments
catalog_name- The identifier of the catalog.schema_name- The identifier of the schema.
Sourcepub fn create_agent(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
name: impl Into<String>,
invocation_protocol: InvocationProtocol,
endpoint: impl Into<String>,
) -> CreateAgentBuilder
pub fn create_agent( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, name: impl Into<String>, invocation_protocol: InvocationProtocol, endpoint: impl Into<String>, ) -> CreateAgentBuilder
Arguments
catalog_name- The identifier of the catalog.schema_name- The identifier of the schema.name- The identifier of the agent.invocation_protocol- The protocol a recipient uses to invoke the agent.endpoint- The agent’s invocation endpoint URL.
Sourcepub fn agent(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
agent_name: impl Into<String>,
) -> AgentClient
pub fn agent( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, agent_name: impl Into<String>, ) -> AgentClient
Access the agent resource scoped to the given name.
Sourcepub fn agent_from_full_name(&self, full_name: impl Into<String>) -> AgentClient
pub fn agent_from_full_name(&self, full_name: impl Into<String>) -> AgentClient
Access the agent resource from its dot-joined full name.
Sourcepub fn list_catalogs(&self) -> ListCatalogsBuilder
pub fn list_catalogs(&self) -> ListCatalogsBuilder
List catalogs
Gets an array of catalogs in the metastore. If the caller is the metastore admin, all catalogs will be retrieved. Otherwise, only catalogs owned by the caller (or for which the caller has the USE_CATALOG privilege) will be retrieved. There is no guarantee of a specific ordering of the elements in the array.
Sourcepub fn create_catalog(&self, name: impl Into<String>) -> CreateCatalogBuilder
pub fn create_catalog(&self, name: impl Into<String>) -> CreateCatalogBuilder
Create a new catalog
Creates a new catalog instance in the parent metastore if the caller is a metastore admin or has the CREATE_CATALOG privilege.
Arguments
name- Name of catalog.
Sourcepub fn catalog(&self, catalog_name: impl Into<String>) -> CatalogClient
pub fn catalog(&self, catalog_name: impl Into<String>) -> CatalogClient
Access the catalog resource scoped to the given name.
pub fn list_credentials(&self) -> ListCredentialsBuilder
Sourcepub fn create_credential(
&self,
name: impl Into<String>,
purpose: Purpose,
) -> CreateCredentialBuilder
pub fn create_credential( &self, name: impl Into<String>, purpose: Purpose, ) -> CreateCredentialBuilder
Arguments
name- The credential name. The name must be unique among storage and service credentials within the metastore.purpose- Indicates the purpose of the credential.
Sourcepub fn credential(&self, credential_name: impl Into<String>) -> CredentialClient
pub fn credential(&self, credential_name: impl Into<String>) -> CredentialClient
Access the credential resource scoped to the given name.
Sourcepub fn list_entity_tag_assignments(
&self,
entity_type: impl Into<String>,
entity_name: impl Into<String>,
) -> ListEntityTagAssignmentsBuilder
pub fn list_entity_tag_assignments( &self, entity_type: impl Into<String>, entity_name: impl Into<String>, ) -> ListEntityTagAssignmentsBuilder
List entity tag assignments
Gets the tag assignments for the specified entity.
Arguments
entity_type- The type of the entity whose tag assignments to list.entity_name- The fully qualified name of the entity whose tag assignments to list.
Sourcepub fn create_entity_tag_assignment(
&self,
tag_assignment: EntityTagAssignment,
) -> CreateEntityTagAssignmentBuilder
pub fn create_entity_tag_assignment( &self, tag_assignment: EntityTagAssignment, ) -> CreateEntityTagAssignmentBuilder
Create an entity tag assignment
Assigns a tag to a Unity Catalog entity.
Arguments
tag_assignment- The tag assignment to create.
Sourcepub fn get_entity_tag_assignment(
&self,
entity_type: impl Into<String>,
entity_name: impl Into<String>,
tag_key: impl Into<String>,
) -> GetEntityTagAssignmentBuilder
pub fn get_entity_tag_assignment( &self, entity_type: impl Into<String>, entity_name: impl Into<String>, tag_key: impl Into<String>, ) -> GetEntityTagAssignmentBuilder
Get an entity tag assignment
Gets the tag assignment for the specified entity and tag key.
Arguments
entity_type- The type of the entity to which the tag is assigned.entity_name- The fully qualified name of the entity to which the tag is assigned.tag_key- The key of the tag.
Sourcepub fn update_entity_tag_assignment(
&self,
entity_type: impl Into<String>,
entity_name: impl Into<String>,
tag_key: impl Into<String>,
tag_assignment: EntityTagAssignment,
) -> UpdateEntityTagAssignmentBuilder
pub fn update_entity_tag_assignment( &self, entity_type: impl Into<String>, entity_name: impl Into<String>, tag_key: impl Into<String>, tag_assignment: EntityTagAssignment, ) -> UpdateEntityTagAssignmentBuilder
Update an entity tag assignment
Updates the tag assignment for the specified entity and tag key.
Arguments
entity_type- The type of the entity to which the tag is assigned.entity_name- The fully qualified name of the entity to which the tag is assigned.tag_key- The key of the tag to update.tag_assignment- The tag assignment with the updated fields.
Sourcepub fn delete_entity_tag_assignment(
&self,
entity_type: impl Into<String>,
entity_name: impl Into<String>,
tag_key: impl Into<String>,
) -> DeleteEntityTagAssignmentBuilder
pub fn delete_entity_tag_assignment( &self, entity_type: impl Into<String>, entity_name: impl Into<String>, tag_key: impl Into<String>, ) -> DeleteEntityTagAssignmentBuilder
Delete an entity tag assignment
Deletes the tag assignment for the specified entity and tag key.
Arguments
entity_type- The type of the entity to which the tag is assigned.entity_name- The fully qualified name of the entity to which the tag is assigned.tag_key- The key of the tag to delete.
Sourcepub fn list_external_locations(&self) -> ListExternalLocationsBuilder
pub fn list_external_locations(&self) -> ListExternalLocationsBuilder
List external locations
Sourcepub fn create_external_location(
&self,
name: impl Into<String>,
url: impl Into<String>,
credential_name: impl Into<String>,
) -> CreateExternalLocationBuilder
pub fn create_external_location( &self, name: impl Into<String>, url: impl Into<String>, credential_name: impl Into<String>, ) -> CreateExternalLocationBuilder
Create a new external location
Arguments
name- Name of external location.url- Path URL of the external location.credential_name- Name of the storage credential used with this location.
Sourcepub fn external_location(
&self,
external_location_name: impl Into<String>,
) -> ExternalLocationClient
pub fn external_location( &self, external_location_name: impl Into<String>, ) -> ExternalLocationClient
Access the external_location resource scoped to the given name.
Sourcepub fn list_functions(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> ListFunctionsBuilder
pub fn list_functions( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> ListFunctionsBuilder
List functions
List functions within the specified parent catalog and schema. If the caller is the metastore admin, all functions are returned in the response. Otherwise, the caller must have USE_CATALOG on the parent catalog and USE_SCHEMA on the parent schema, and the function must either be owned by the caller or have SELECT on the function.
Arguments
catalog_name- Name of parent catalog for functions of interest.schema_name- Parent schema of functions.
Sourcepub fn create_function(
&self,
function_info: CreateFunction,
) -> CreateFunctionBuilder
pub fn create_function( &self, function_info: CreateFunction, ) -> CreateFunctionBuilder
Create a function
Creates a new function. The caller must be a metastore admin or have the CREATE_FUNCTION privilege on the parent catalog and schema.
Arguments
function_info- The function to create.
Sourcepub fn function(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
function_name: impl Into<String>,
) -> FunctionClient
pub fn function( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, function_name: impl Into<String>, ) -> FunctionClient
Access the function resource scoped to the given name.
Sourcepub fn function_from_full_name(
&self,
full_name: impl Into<String>,
) -> FunctionClient
pub fn function_from_full_name( &self, full_name: impl Into<String>, ) -> FunctionClient
Access the function resource from its dot-joined full name.
Sourcepub fn list_model_versions(
&self,
full_name: impl Into<String>,
) -> ListModelVersionsBuilder
pub fn list_model_versions( &self, full_name: impl Into<String>, ) -> ListModelVersionsBuilder
List model versions
List the model versions of the specified registered model. If the caller is the metastore admin, all model versions are returned. Otherwise, the caller must have the appropriate privileges on the parent model.
Arguments
full_name- The full three-level name of the registered model (catalog.schema.model) whose versions are being listed.
Sourcepub fn create_model_version(
&self,
model_name: impl Into<String>,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
source: impl Into<String>,
) -> CreateModelVersionBuilder
pub fn create_model_version( &self, model_name: impl Into<String>, catalog_name: impl Into<String>, schema_name: impl Into<String>, source: impl Into<String>, ) -> CreateModelVersionBuilder
Create a model version
Creates a new model version in PENDING_REGISTRATION status. The server assigns the version number and a storage location for the artifacts. The caller must be a metastore admin or the owner of the parent registered model.
Arguments
model_name- Name of the parent registered model, relative to parent schema.catalog_name- Name of parent catalog.schema_name- Name of parent schema.source- URI indicating the location of the source artifacts (e.g. an MLflow run artifact path) used to create the model version.
Sourcepub fn get_model_version(
&self,
full_name: impl Into<String>,
version: i64,
) -> GetModelVersionBuilder
pub fn get_model_version( &self, full_name: impl Into<String>, version: i64, ) -> GetModelVersionBuilder
Get a model version
Gets a model version by its parent model name and version number.
Arguments
full_name- The full three-level name of the parent registered model (catalog.schema.model).version- The integer version number of the model version.
Sourcepub fn update_model_version(
&self,
full_name: impl Into<String>,
version: i64,
) -> UpdateModelVersionBuilder
pub fn update_model_version( &self, full_name: impl Into<String>, version: i64, ) -> UpdateModelVersionBuilder
Update a model version
Updates the model version that matches the supplied name and version.
Arguments
full_name- The full three-level name of the parent registered model (catalog.schema.model).version- The integer version number of the model version.
Sourcepub fn delete_model_version(
&self,
full_name: impl Into<String>,
version: i64,
) -> DeleteModelVersionBuilder
pub fn delete_model_version( &self, full_name: impl Into<String>, version: i64, ) -> DeleteModelVersionBuilder
Delete a model version
Deletes the model version that matches the supplied name and version. For the deletion to succeed, the caller must be the owner of the parent registered model.
Arguments
full_name- The full three-level name of the parent registered model (catalog.schema.model).version- The integer version number of the model version.
Sourcepub fn finalize_model_version(
&self,
full_name: impl Into<String>,
version: i64,
) -> FinalizeModelVersionBuilder
pub fn finalize_model_version( &self, full_name: impl Into<String>, version: i64, ) -> FinalizeModelVersionBuilder
Finalize a model version
Transitions a model version to READY once all artifacts have been written to its storage location.
Arguments
full_name- The full three-level name of the parent registered model (catalog.schema.model).version- The integer version number of the model version to finalize.
Sourcepub fn list_policies(
&self,
on_securable_type: impl Into<String>,
on_securable_fullname: impl Into<String>,
) -> ListPoliciesBuilder
pub fn list_policies( &self, on_securable_type: impl Into<String>, on_securable_fullname: impl Into<String>, ) -> ListPoliciesBuilder
List policies
Gets an array of policies defined on the specified securable. There is no guarantee of a specific ordering of the elements in the array.
Arguments
on_securable_type- The type of the securable to list policies on.
Supported values: catalogs, schemas, tables.
on_securable_fullname- The fully qualified name of the securable to list policies on.
Sourcepub fn policy(&self, policy_name: impl Into<String>) -> PolicyClient
pub fn policy(&self, policy_name: impl Into<String>) -> PolicyClient
Access the policy resource scoped to the given name.
Sourcepub fn list_providers(&self) -> ListProvidersBuilder
pub fn list_providers(&self) -> ListProvidersBuilder
List providers.
Sourcepub fn create_provider(
&self,
name: impl Into<String>,
authentication_type: ProviderAuthenticationType,
) -> CreateProviderBuilder
pub fn create_provider( &self, name: impl Into<String>, authentication_type: ProviderAuthenticationType, ) -> CreateProviderBuilder
Create a new provider.
Arguments
name- Name of the provider.authentication_type- The delta sharing authentication type.
Sourcepub fn provider(&self, provider_name: impl Into<String>) -> ProviderClient
pub fn provider(&self, provider_name: impl Into<String>) -> ProviderClient
Access the provider resource scoped to the given name.
Sourcepub fn list_recipients(&self) -> ListRecipientsBuilder
pub fn list_recipients(&self) -> ListRecipientsBuilder
List recipients.
Sourcepub fn create_recipient(
&self,
name: impl Into<String>,
authentication_type: AuthenticationType,
owner: impl Into<String>,
) -> CreateRecipientBuilder
pub fn create_recipient( &self, name: impl Into<String>, authentication_type: AuthenticationType, owner: impl Into<String>, ) -> CreateRecipientBuilder
Create a new recipient.
Arguments
name- Name of the recipient.authentication_type- The delta sharing authentication type.owner- Username of the recipient owner.
Sourcepub fn recipient(&self, recipient_name: impl Into<String>) -> RecipientClient
pub fn recipient(&self, recipient_name: impl Into<String>) -> RecipientClient
Access the recipient resource scoped to the given name.
Sourcepub fn list_registered_models(&self) -> ListRegisteredModelsBuilder
pub fn list_registered_models(&self) -> ListRegisteredModelsBuilder
List registered models
List registered models within the specified parent catalog and schema. If the caller is the metastore admin, all registered models are returned in the response. Otherwise, the caller must have USE_CATALOG on the parent catalog and USE_SCHEMA on the parent schema, and the model must either be owned by the caller or the caller must have a privilege on the model.
Sourcepub fn create_registered_model(
&self,
name: impl Into<String>,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> CreateRegisteredModelBuilder
pub fn create_registered_model( &self, name: impl Into<String>, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> CreateRegisteredModelBuilder
Create a registered model
Creates a new registered model. The caller must be a metastore admin or have the CREATE_MODEL privilege on the parent catalog and schema.
Arguments
name- Name of registered model, relative to parent schema.catalog_name- Name of parent catalog.schema_name- Name of parent schema.
Sourcepub fn registered_model(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
registered_model_name: impl Into<String>,
) -> RegisteredModelClient
pub fn registered_model( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, registered_model_name: impl Into<String>, ) -> RegisteredModelClient
Access the registered_model resource scoped to the given name.
Sourcepub fn registered_model_from_full_name(
&self,
full_name: impl Into<String>,
) -> RegisteredModelClient
pub fn registered_model_from_full_name( &self, full_name: impl Into<String>, ) -> RegisteredModelClient
Access the registered_model resource from its dot-joined full name.
Sourcepub fn list_schemas(
&self,
catalog_name: impl Into<String>,
) -> ListSchemasBuilder
pub fn list_schemas( &self, catalog_name: impl Into<String>, ) -> ListSchemasBuilder
Gets an array of schemas for a catalog in the metastore. If the caller is the metastore admin or the owner of the parent catalog, all schemas for the catalog will be retrieved. Otherwise, only schemas owned by the caller (or for which the caller has the USE_SCHEMA privilege) will be retrieved. There is no guarantee of a specific ordering of the elements in the array.
Arguments
catalog_name- Name of parent catalog.
Sourcepub fn create_schema(
&self,
name: impl Into<String>,
catalog_name: impl Into<String>,
) -> CreateSchemaBuilder
pub fn create_schema( &self, name: impl Into<String>, catalog_name: impl Into<String>, ) -> CreateSchemaBuilder
Creates a new schema for catalog in the Metatastore. The caller must be a metastore admin, or have the CREATE_SCHEMA privilege in the parent catalog.
Arguments
name- Name of schema, relative to parent catalog.catalog_name- Name of parent catalog.
Sourcepub fn schema(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> SchemaClient
pub fn schema( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> SchemaClient
Access the schema resource scoped to the given name.
Sourcepub fn schema_from_full_name(
&self,
full_name: impl Into<String>,
) -> SchemaClient
pub fn schema_from_full_name( &self, full_name: impl Into<String>, ) -> SchemaClient
Access the schema resource from its dot-joined full name.
List shares.
Access the share resource scoped to the given name.
Sourcepub fn create_staging_table(
&self,
name: impl Into<String>,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> CreateStagingTableBuilder
pub fn create_staging_table( &self, name: impl Into<String>, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> CreateStagingTableBuilder
Creates a new staging table, allocating an immutable table id and a storage location under the parent schema/catalog managed storage root. The caller must have the CREATE privilege on the parent schema.
Arguments
name- Name of the staging table, relative to the parent schema.catalog_name- Name of the parent catalog.schema_name- Name of the parent schema relative to its parent catalog.
Sourcepub fn staging_table(
&self,
staging_table_name: impl Into<String>,
) -> StagingTableClient
pub fn staging_table( &self, staging_table_name: impl Into<String>, ) -> StagingTableClient
Access the staging_table resource scoped to the given name.
Sourcepub fn list_table_summaries(
&self,
catalog_name: impl Into<String>,
) -> ListTableSummariesBuilder
pub fn list_table_summaries( &self, catalog_name: impl Into<String>, ) -> ListTableSummariesBuilder
Gets an array of summaries for tables for a schema and catalog within the metastore. The table summaries returned are either:
- summaries for tables (within the current metastore and parent catalog and schema), when the user is a metastore admin, or:
- summaries for tables and schemas (within the current metastore and parent catalog) for which the user has ownership or the SELECT privilege on the table and ownership or USE_SCHEMA privilege on the schema, provided that the user also has ownership or the USE_CATALOG privilege on the parent catalog.
There is no guarantee of a specific ordering of the elements in the array.
Arguments
catalog_name- Name of parent catalog for tables of interest.
Sourcepub fn list_tables(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> ListTablesBuilder
pub fn list_tables( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> ListTablesBuilder
Gets an array of all tables for the current metastore under the parent catalog and schema.
The caller must be a metastore admin or an owner of (or have the SELECT privilege on) the table. For the latter case, the caller must also be the owner or have the USE_CATALOG privilege on the parent catalog and the USE_SCHEMA privilege on the parent schema. There is no guarantee of a specific ordering of the elements in the array.
Arguments
catalog_name- Name of parent catalog for tables of interest.schema_name- Name of parent schema for tables of interest.
Sourcepub fn create_table(
&self,
name: impl Into<String>,
schema_name: impl Into<String>,
catalog_name: impl Into<String>,
table_type: TableType,
data_source_format: DataSourceFormat,
) -> CreateTableBuilder
pub fn create_table( &self, name: impl Into<String>, schema_name: impl Into<String>, catalog_name: impl Into<String>, table_type: TableType, data_source_format: DataSourceFormat, ) -> CreateTableBuilder
Create a table
Arguments
name- Name of table, relative to parent schema.schema_name- Name of parent schema relative to its parent catalog.catalog_name- Name of parent catalog.
Sourcepub fn table(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
table_name: impl Into<String>,
) -> TableClient
pub fn table( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, table_name: impl Into<String>, ) -> TableClient
Access the table resource scoped to the given name.
Sourcepub fn table_from_full_name(&self, full_name: impl Into<String>) -> TableClient
pub fn table_from_full_name(&self, full_name: impl Into<String>) -> TableClient
Access the table resource from its dot-joined full name.
Sourcepub fn list_tag_policies(&self) -> ListTagPoliciesBuilder
pub fn list_tag_policies(&self) -> ListTagPoliciesBuilder
List tag policies
Gets an array of tag policies. There is no guarantee of a specific ordering of the elements in the array.
Sourcepub fn create_tag_policy(&self, tag_policy: TagPolicy) -> CreateTagPolicyBuilder
pub fn create_tag_policy(&self, tag_policy: TagPolicy) -> CreateTagPolicyBuilder
Create a new tag policy
Creates a new governed tag definition.
Arguments
tag_policy- The tag policy to create.
Sourcepub fn tag_policy(&self, tag_policy_name: impl Into<String>) -> TagPolicyClient
pub fn tag_policy(&self, tag_policy_name: impl Into<String>) -> TagPolicyClient
Access the tag_policy resource scoped to the given name.
Sourcepub fn generate_temporary_table_credentials(
&self,
table_id: impl Into<String>,
operation: Operation,
) -> GenerateTemporaryTableCredentialsBuilder
pub fn generate_temporary_table_credentials( &self, table_id: impl Into<String>, operation: Operation, ) -> GenerateTemporaryTableCredentialsBuilder
Generate a new set of credentials for a table.
Arguments
table_id- UUID of the table to read or write.operation- The operation performed against the table data, either READ or READ_WRITE. If READ_WRITE is specified, the credentials returned will have write permissions, otherwise, it will be read only.
Sourcepub fn generate_temporary_path_credentials(
&self,
url: impl Into<String>,
operation: Operation,
) -> GenerateTemporaryPathCredentialsBuilder
pub fn generate_temporary_path_credentials( &self, url: impl Into<String>, operation: Operation, ) -> GenerateTemporaryPathCredentialsBuilder
Generate a new set of credentials for a path.
Arguments
url- URL for path-based access.operation- The operation being performed on the path.
Sourcepub fn generate_temporary_volume_credentials(
&self,
volume_id: impl Into<String>,
operation: Operation,
) -> GenerateTemporaryVolumeCredentialsBuilder
pub fn generate_temporary_volume_credentials( &self, volume_id: impl Into<String>, operation: Operation, ) -> GenerateTemporaryVolumeCredentialsBuilder
Generate a new set of credentials for a volume.
The metastore must have the external_access_enabled flag set to true
(default false). The caller must have the EXTERNAL_USE_SCHEMA
privilege on the parent schema (granted by a catalog owner).
Arguments
volume_id- UUID of the volume to read or write.operation- The operation performed against the volume data, either READ_VOLUME or WRITE_VOLUME. If WRITE_VOLUME is specified, the credentials returned will have write permissions, otherwise, it will be read only.
Sourcepub fn generate_temporary_model_version_credentials(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
model_name: impl Into<String>,
version: i64,
operation: Operation,
) -> GenerateTemporaryModelVersionCredentialsBuilder
pub fn generate_temporary_model_version_credentials( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, model_name: impl Into<String>, version: i64, operation: Operation, ) -> GenerateTemporaryModelVersionCredentialsBuilder
Generate a new set of credentials for a model version.
The metastore must have the external_access_enabled flag set to true
(default false). The caller must have the EXTERNAL_USE_SCHEMA
privilege on the parent schema (granted by a catalog owner).
Arguments
catalog_name- Name of parent catalog of the model version.schema_name- Name of parent schema of the model version.model_name- Name of the parent registered model.version- The integer version number of the model version.operation- The operation performed against the model version data, either READ_MODEL_VERSION or READ_WRITE_MODEL_VERSION. If READ_WRITE_MODEL_VERSION is specified, the credentials returned will have write permissions, otherwise, it will be read only.
Sourcepub fn list_volumes(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
) -> ListVolumesBuilder
pub fn list_volumes( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, ) -> ListVolumesBuilder
Lists volumes.
Arguments
catalog_name- The identifier of the catalogschema_name- The identifier of the schema
Sourcepub fn create_volume(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
name: impl Into<String>,
volume_type: VolumeType,
) -> CreateVolumeBuilder
pub fn create_volume( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, name: impl Into<String>, volume_type: VolumeType, ) -> CreateVolumeBuilder
Arguments
catalog_name- The identifier of the catalogschema_name- The identifier of the schemaname- The identifier of the volumevolume_type- The type of the volume.
An external volume is located in the specified external location. A managed volume is located in the default location which is specified by the parent schema, or the parent catalog, or the Metastore.
Sourcepub fn volume(
&self,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
volume_name: impl Into<String>,
) -> VolumeClient
pub fn volume( &self, catalog_name: impl Into<String>, schema_name: impl Into<String>, volume_name: impl Into<String>, ) -> VolumeClient
Access the volume resource scoped to the given name.
Sourcepub fn volume_from_full_name(
&self,
full_name: impl Into<String>,
) -> VolumeClient
pub fn volume_from_full_name( &self, full_name: impl Into<String>, ) -> VolumeClient
Access the volume resource from its dot-joined full name.
Sourceimpl UnityCatalogClient
impl UnityCatalogClient
Sourcepub fn temporary_credentials(&self) -> TemporaryCredentialClient
pub fn temporary_credentials(&self) -> TemporaryCredentialClient
Ergonomic accessor for the temporary credential vending client.
Wraps the generated low-level client with the hand-written name → UUID resolving helpers
(temporary_table_credential, temporary_volume_credential, temporary_path_credential).
Sourcepub fn delta_v1(&self) -> DeltaV1Client
pub fn delta_v1(&self) -> DeltaV1Client
Ergonomic accessor for the hand-written /delta/v1/ Delta REST API client.
Reuses a generated low-level client’s cloud client and base URL (both carry the same auth + endpoint), so the Delta v1 client shares the aggregate client’s configuration without touching generated code.