pub struct FunctionServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
Sourceimpl FunctionServiceClient
impl FunctionServiceClient
Sourcepub async fn list_functions(
&self,
request: &ListFunctionsRequest,
) -> Result<ListFunctionsResponse>
pub async fn list_functions( &self, request: &ListFunctionsRequest, ) -> Result<ListFunctionsResponse>
List functions
List functions within the specified parent catalog and schema. If the caller is the metastore admin, all functions are returned in the response. Otherwise, the caller must have USE_CATALOG on the parent catalog and USE_SCHEMA on the parent schema, and the function must either be owned by the caller or have SELECT on the function.
Sourcepub async fn create_function(
&self,
request: &CreateFunctionRequest,
) -> Result<Function>
pub async fn create_function( &self, request: &CreateFunctionRequest, ) -> Result<Function>
Create a function
Creates a new function. The caller must be a metastore admin or have the CREATE_FUNCTION privilege on the parent catalog and schema.
Sourcepub async fn get_function(
&self,
request: &GetFunctionRequest,
) -> Result<Function>
pub async fn get_function( &self, request: &GetFunctionRequest, ) -> Result<Function>
Get a function
Gets a function from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the function, or have SELECT on the function.
Sourcepub async fn update_function(
&self,
request: &UpdateFunctionRequest,
) -> Result<Function>
pub async fn update_function( &self, request: &UpdateFunctionRequest, ) -> Result<Function>
Update a function
Updates the function that matches the supplied name. Only the owner of the function can be updated.
Sourcepub async fn delete_function(
&self,
request: &DeleteFunctionRequest,
) -> Result<()>
pub async fn delete_function( &self, request: &DeleteFunctionRequest, ) -> Result<()>
Delete a function
Deletes the function that matches the supplied name. For the deletion to succeed, the caller must be the owner of the function.