pub struct FunctionClient { /* private fields */ }Expand description
A client scoped to a single function.
Implementations
Sourceimpl FunctionClient
impl FunctionClient
Sourcepub fn new(
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
function_name: impl Into<String>,
client: FunctionServiceClient,
) -> Self
pub fn new( catalog_name: impl Into<String>, schema_name: impl Into<String>, function_name: impl Into<String>, client: FunctionServiceClient, ) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn from_full_name(
full_name: impl Into<String>,
client: FunctionServiceClient,
) -> Self
pub fn from_full_name( full_name: impl Into<String>, client: FunctionServiceClient, ) -> Self
Create a function client from its dot-joined full name (e.g. "catalog_name.schema_name.function_name").
Sourcepub fn catalog_name(&self) -> &str
pub fn catalog_name(&self) -> &str
The catalog_name component of this resource’s name.
Sourcepub fn schema_name(&self) -> &str
pub fn schema_name(&self) -> &str
The schema_name component of this resource’s name.
Sourcepub fn full_name(&self) -> String
pub fn full_name(&self) -> String
The fully-qualified name of this resource (its dot-joined name components).
Sourcepub fn get(&self) -> GetFunctionBuilder
pub fn get(&self) -> GetFunctionBuilder
Get a function
Gets a function from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the function, or have SELECT on the function.
Sourcepub fn update(&self) -> UpdateFunctionBuilder
pub fn update(&self) -> UpdateFunctionBuilder
Update a function
Updates the function that matches the supplied name. Only the owner of the function can be updated.
Sourcepub fn delete(&self) -> DeleteFunctionBuilder
pub fn delete(&self) -> DeleteFunctionBuilder
Delete a function
Deletes the function that matches the supplied name. For the deletion to succeed, the caller must be the owner of the function.