pub struct ModelVersionServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
Sourceimpl ModelVersionServiceClient
impl ModelVersionServiceClient
Sourcepub async fn list_model_versions(
&self,
request: &ListModelVersionsRequest,
) -> Result<ListModelVersionsResponse>
pub async fn list_model_versions( &self, request: &ListModelVersionsRequest, ) -> Result<ListModelVersionsResponse>
List model versions
List the model versions of the specified registered model. If the caller is the metastore admin, all model versions are returned. Otherwise, the caller must have the appropriate privileges on the parent model.
Sourcepub async fn create_model_version(
&self,
request: &CreateModelVersionRequest,
) -> Result<ModelVersion>
pub async fn create_model_version( &self, request: &CreateModelVersionRequest, ) -> Result<ModelVersion>
Create a model version
Creates a new model version in PENDING_REGISTRATION status. The server assigns the version number and a storage location for the artifacts. The caller must be a metastore admin or the owner of the parent registered model.
Sourcepub async fn get_model_version(
&self,
request: &GetModelVersionRequest,
) -> Result<ModelVersion>
pub async fn get_model_version( &self, request: &GetModelVersionRequest, ) -> Result<ModelVersion>
Get a model version
Gets a model version by its parent model name and version number.
Sourcepub async fn update_model_version(
&self,
request: &UpdateModelVersionRequest,
) -> Result<ModelVersion>
pub async fn update_model_version( &self, request: &UpdateModelVersionRequest, ) -> Result<ModelVersion>
Update a model version
Updates the model version that matches the supplied name and version.
Sourcepub async fn delete_model_version(
&self,
request: &DeleteModelVersionRequest,
) -> Result<()>
pub async fn delete_model_version( &self, request: &DeleteModelVersionRequest, ) -> Result<()>
Delete a model version
Deletes the model version that matches the supplied name and version. For the deletion to succeed, the caller must be the owner of the parent registered model.
Sourcepub async fn finalize_model_version(
&self,
request: &FinalizeModelVersionRequest,
) -> Result<ModelVersion>
pub async fn finalize_model_version( &self, request: &FinalizeModelVersionRequest, ) -> Result<ModelVersion>
Finalize a model version
Transitions a model version to READY once all artifacts have been written to its storage location.