pub struct RegisteredModelClient { /* private fields */ }Expand description
A client scoped to a single registered_model.
Implementations
Sourceimpl RegisteredModelClient
impl RegisteredModelClient
Sourcepub fn new(
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
registered_model_name: impl Into<String>,
client: RegisteredModelServiceClient,
) -> Self
pub fn new( catalog_name: impl Into<String>, schema_name: impl Into<String>, registered_model_name: impl Into<String>, client: RegisteredModelServiceClient, ) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn from_full_name(
full_name: impl Into<String>,
client: RegisteredModelServiceClient,
) -> Self
pub fn from_full_name( full_name: impl Into<String>, client: RegisteredModelServiceClient, ) -> Self
Create a registered_model client from its dot-joined full name (e.g. "catalog_name.schema_name.registered_model_name").
Sourcepub fn catalog_name(&self) -> &str
pub fn catalog_name(&self) -> &str
The catalog_name component of this resource’s name.
Sourcepub fn schema_name(&self) -> &str
pub fn schema_name(&self) -> &str
The schema_name component of this resource’s name.
Sourcepub fn full_name(&self) -> String
pub fn full_name(&self) -> String
The fully-qualified name of this resource (its dot-joined name components).
Sourcepub fn get(&self) -> GetRegisteredModelBuilder
pub fn get(&self) -> GetRegisteredModelBuilder
Get a registered model
Gets a registered model from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the registered model, or have a privilege on the registered model.
Sourcepub fn update(&self) -> UpdateRegisteredModelBuilder
pub fn update(&self) -> UpdateRegisteredModelBuilder
Update a registered model
Updates the registered model that matches the supplied name.
Sourcepub fn delete(&self) -> DeleteRegisteredModelBuilder
pub fn delete(&self) -> DeleteRegisteredModelBuilder
Delete a registered model
Deletes the registered model that matches the supplied name. For the deletion to succeed, the caller must be the owner of the registered model.