pub struct SchemaServiceClient { /* private fields */ }Expand description
HTTP client for service operations
Implementations
Sourceimpl SchemaServiceClient
impl SchemaServiceClient
Sourcepub async fn list_schemas(
&self,
request: &ListSchemasRequest,
) -> Result<ListSchemasResponse>
pub async fn list_schemas( &self, request: &ListSchemasRequest, ) -> Result<ListSchemasResponse>
Gets an array of schemas for a catalog in the metastore. If the caller is the metastore admin or the owner of the parent catalog, all schemas for the catalog will be retrieved. Otherwise, only schemas owned by the caller (or for which the caller has the USE_SCHEMA privilege) will be retrieved. There is no guarantee of a specific ordering of the elements in the array.
Sourcepub async fn create_schema(
&self,
request: &CreateSchemaRequest,
) -> Result<Schema>
pub async fn create_schema( &self, request: &CreateSchemaRequest, ) -> Result<Schema>
Creates a new schema for catalog in the Metatastore. The caller must be a metastore admin, or have the CREATE_SCHEMA privilege in the parent catalog.
Sourcepub async fn get_schema(&self, request: &GetSchemaRequest) -> Result<Schema>
pub async fn get_schema(&self, request: &GetSchemaRequest) -> Result<Schema>
Gets the specified schema within the metastore. The caller must be a metastore admin, the owner of the schema, or a user that has the USE_SCHEMA privilege on the schema.
Sourcepub async fn update_schema(
&self,
request: &UpdateSchemaRequest,
) -> Result<Schema>
pub async fn update_schema( &self, request: &UpdateSchemaRequest, ) -> Result<Schema>
Updates a schema for a catalog. The caller must be the owner of the schema or a metastore admin. If the caller is a metastore admin, only the owner field can be changed in the update. If the name field must be updated, the caller must be a metastore admin or have the CREATE_SCHEMA privilege on the parent catalog.
Sourcepub async fn delete_schema(&self, request: &DeleteSchemaRequest) -> Result<()>
pub async fn delete_schema(&self, request: &DeleteSchemaRequest) -> Result<()>
Deletes the specified schema from the parent catalog. The caller must be the owner of the schema or an owner of the parent catalog.