pub struct SchemaClient { /* private fields */ }Expand description
A client scoped to a single schema.
Implementations
Sourceimpl SchemaClient
impl SchemaClient
Sourcepub fn new(
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
client: SchemaServiceClient,
) -> Self
pub fn new( catalog_name: impl Into<String>, schema_name: impl Into<String>, client: SchemaServiceClient, ) -> Self
Create a client bound to the resource’s name components.
Sourcepub fn from_full_name(
full_name: impl Into<String>,
client: SchemaServiceClient,
) -> Self
pub fn from_full_name( full_name: impl Into<String>, client: SchemaServiceClient, ) -> Self
Create a schema client from its dot-joined full name (e.g. "catalog_name.schema_name").
Sourcepub fn catalog_name(&self) -> &str
pub fn catalog_name(&self) -> &str
The catalog_name component of this resource’s name.
Sourcepub fn full_name(&self) -> String
pub fn full_name(&self) -> String
The fully-qualified name of this resource (its dot-joined name components).
Sourcepub fn get(&self) -> GetSchemaBuilder
pub fn get(&self) -> GetSchemaBuilder
Gets the specified schema within the metastore. The caller must be a metastore admin, the owner of the schema, or a user that has the USE_SCHEMA privilege on the schema.
Sourcepub fn update(&self) -> UpdateSchemaBuilder
pub fn update(&self) -> UpdateSchemaBuilder
Updates a schema for a catalog. The caller must be the owner of the schema or a metastore admin. If the caller is a metastore admin, only the owner field can be changed in the update. If the name field must be updated, the caller must be a metastore admin or have the CREATE_SCHEMA privilege on the parent catalog.
Sourcepub fn delete(&self) -> DeleteSchemaBuilder
pub fn delete(&self) -> DeleteSchemaBuilder
Deletes the specified schema from the parent catalog. The caller must be the owner of the schema or an owner of the parent catalog.
Sourcepub fn agent(&self, agent_name: impl Into<String>) -> AgentClient
pub fn agent(&self, agent_name: impl Into<String>) -> AgentClient
Access a agent within this resource.
Sourcepub fn create_agent(
&self,
name: impl Into<String>,
invocation_protocol: InvocationProtocol,
endpoint: impl Into<String>,
) -> CreateAgentBuilder
pub fn create_agent( &self, name: impl Into<String>, invocation_protocol: InvocationProtocol, endpoint: impl Into<String>, ) -> CreateAgentBuilder
Create a agent within this resource.
Sourcepub fn list_agents(&self) -> ListAgentsBuilder
pub fn list_agents(&self) -> ListAgentsBuilder
List agent resources within this resource.
Sourcepub fn agent_skill(
&self,
agent_skill_name: impl Into<String>,
) -> AgentSkillClient
pub fn agent_skill( &self, agent_skill_name: impl Into<String>, ) -> AgentSkillClient
Access a agent_skill within this resource.
Sourcepub fn create_agent_skill(
&self,
name: impl Into<String>,
agent_skill_type: AgentSkillType,
) -> CreateAgentSkillBuilder
pub fn create_agent_skill( &self, name: impl Into<String>, agent_skill_type: AgentSkillType, ) -> CreateAgentSkillBuilder
Create a agent_skill within this resource.
Sourcepub fn list_agent_skills(&self) -> ListAgentSkillsBuilder
pub fn list_agent_skills(&self) -> ListAgentSkillsBuilder
List agent_skill resources within this resource.
Sourcepub fn function(&self, function_name: impl Into<String>) -> FunctionClient
pub fn function(&self, function_name: impl Into<String>) -> FunctionClient
Access a function within this resource.
Sourcepub fn create_function(
&self,
function_info: CreateFunction,
) -> CreateFunctionBuilder
pub fn create_function( &self, function_info: CreateFunction, ) -> CreateFunctionBuilder
Create a function within this resource.
Sourcepub fn list_functions(&self) -> ListFunctionsBuilder
pub fn list_functions(&self) -> ListFunctionsBuilder
List function resources within this resource.
Sourcepub fn registered_model(
&self,
registered_model_name: impl Into<String>,
) -> RegisteredModelClient
pub fn registered_model( &self, registered_model_name: impl Into<String>, ) -> RegisteredModelClient
Access a registered_model within this resource.
Sourcepub fn create_registered_model(
&self,
name: impl Into<String>,
) -> CreateRegisteredModelBuilder
pub fn create_registered_model( &self, name: impl Into<String>, ) -> CreateRegisteredModelBuilder
Create a registered_model within this resource.
Sourcepub fn list_registered_models(&self) -> ListRegisteredModelsBuilder
pub fn list_registered_models(&self) -> ListRegisteredModelsBuilder
List registered_model resources within this resource.
Sourcepub fn table(&self, table_name: impl Into<String>) -> TableClient
pub fn table(&self, table_name: impl Into<String>) -> TableClient
Access a table within this resource.
Sourcepub fn create_table(
&self,
name: impl Into<String>,
table_type: TableType,
data_source_format: DataSourceFormat,
) -> CreateTableBuilder
pub fn create_table( &self, name: impl Into<String>, table_type: TableType, data_source_format: DataSourceFormat, ) -> CreateTableBuilder
Create a table within this resource.
Sourcepub fn list_tables(&self) -> ListTablesBuilder
pub fn list_tables(&self) -> ListTablesBuilder
List table resources within this resource.
Sourcepub fn volume(&self, volume_name: impl Into<String>) -> VolumeClient
pub fn volume(&self, volume_name: impl Into<String>) -> VolumeClient
Access a volume within this resource.
Sourcepub fn create_volume(
&self,
name: impl Into<String>,
volume_type: VolumeType,
) -> CreateVolumeBuilder
pub fn create_volume( &self, name: impl Into<String>, volume_type: VolumeType, ) -> CreateVolumeBuilder
Create a volume within this resource.
Sourcepub fn list_volumes(&self) -> ListVolumesBuilder
pub fn list_volumes(&self) -> ListVolumesBuilder
List volume resources within this resource.