TableServiceClient

Struct TableServiceClient 

pub struct TableServiceClient { /* private fields */ }
HTTP client for service operations

Implementations

Source

impl TableServiceClient

pub fn new(client: Transport, base_url: Url) -> Self

Create a new client instance

pub async fn list_table_summaries( &self, request: &ListTableSummariesRequest, ) -> Result<ListTableSummariesResponse>

Gets an array of summaries for tables for a schema and catalog within the metastore. The table summaries returned are either:

  • summaries for tables (within the current metastore and parent catalog and schema), when the user is a metastore admin, or:
  • summaries for tables and schemas (within the current metastore and parent catalog) for which the user has ownership or the SELECT privilege on the table and ownership or USE_SCHEMA privilege on the schema, provided that the user also has ownership or the USE_CATALOG privilege on the parent catalog.

There is no guarantee of a specific ordering of the elements in the array.

pub async fn list_tables( &self, request: &ListTablesRequest, ) -> Result<ListTablesResponse>

Gets an array of all tables for the current metastore under the parent catalog and schema.

The caller must be a metastore admin or an owner of (or have the SELECT privilege on) the table. For the latter case, the caller must also be the owner or have the USE_CATALOG privilege on the parent catalog and the USE_SCHEMA privilege on the parent schema. There is no guarantee of a specific ordering of the elements in the array.

pub async fn create_table(&self, request: &CreateTableRequest) -> Result<Table>

Create a table

pub async fn get_table(&self, request: &GetTableRequest) -> Result<Table>

Get a table

pub async fn get_table_exists( &self, request: &GetTableExistsRequest, ) -> Result<GetTableExistsResponse>

Get boolean reflecting if table exists

pub async fn delete_table(&self, request: &DeleteTableRequest) -> Result<()>

Delete a table