pub struct GenerateTemporaryPathCredentialsBuilder { /* private fields */ }Expand description
Builder for temporary path credentials
Implementations
Sourceimpl GenerateTemporaryPathCredentialsBuilder
impl GenerateTemporaryPathCredentialsBuilder
Sourcepub fn with_dry_run(self, dry_run: impl Into<Option<bool>>) -> Self
pub fn with_dry_run(self, dry_run: impl Into<Option<bool>>) -> Self
When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.