pub struct TemporaryCredentialClient { /* private fields */ }Implementations
Sourceimpl TemporaryCredentialClient
impl TemporaryCredentialClient
pub fn new_with_url(client: CloudClient, base_url: Url) -> Self
pub fn new(client: TemporaryCredentialClientBase) -> Self
Sourcepub async fn temporary_table_credential(
&self,
table: impl Into<TableReference>,
operation: TableOperation,
) -> Result<(TemporaryCredential, Uuid)>
pub async fn temporary_table_credential( &self, table: impl Into<TableReference>, operation: TableOperation, ) -> Result<(TemporaryCredential, Uuid)>
pub async fn temporary_path_credential( &self, path: impl IntoUrl, operation: PathOperation, dry_run: impl Into<Option<bool>>, ) -> Result<(TemporaryCredential, Url)>
Sourcepub async fn temporary_volume_credential(
&self,
volume: impl Into<VolumeReference>,
operation: VolumeOperation,
) -> Result<(TemporaryCredential, Uuid)>
pub async fn temporary_volume_credential( &self, volume: impl Into<VolumeReference>, operation: VolumeOperation, ) -> Result<(TemporaryCredential, Uuid)>
Get a temporary credential for reading or writing to a volume.
Parameters
volume: The volume to get a temporary credential for. May be either aVolumeReference::Id(UUID, preferred when known) or aVolumeReference::Namein three-level dotted form (catalog.schema.volume). Names are resolved to IDs by issuing aGetVolumerequest.operation: Whether the credentials should grant read-only or read-write access.
Returns
A tuple containing the temporary credential and the resolved volume ID.
Server requirements
The Unity Catalog metastore must have external_access_enabled = true
and the caller must hold EXTERNAL_USE_SCHEMA on the parent schema.